hwc: Add 60 progressive framerate to the table
Add missing 60p to the standard refresh rate table to avoid fps
fluctation b/w 59 and 60 while playing a 60 fps clip
Change-Id: I8cdc28a604ead0970e5cc6e8d64835b0c646e1d3
CRs-fixed: 755186
diff --git a/libhwcomposer/hwc_utils.cpp b/libhwcomposer/hwc_utils.cpp
index 300e90a..9d53bda 100644
--- a/libhwcomposer/hwc_utils.cpp
+++ b/libhwcomposer/hwc_utils.cpp
@@ -81,8 +81,8 @@
namespace qhwc {
-//Std refresh rates for digital videos- 24p, 30p and 48p
-uint32_t stdRefreshRates[] = { 30, 24, 48 };
+// Std refresh rates for digital videos- 24p, 30p, 48p and 60p
+uint32_t stdRefreshRates[] = { 30, 24, 48, 60 };
bool isValidResolution(hwc_context_t *ctx, uint32_t xres, uint32_t yres)
{